@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get XML.
 has xml => (
@@ -195,7 +195,9 @@ L<namespace::clean>.
 L<Map::Tube>,
 L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
+L<Map::Tube::Plugin::FuzzyFind>,
 L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Shortest>,
 L<Map::Tube::Text::Table>,
 L<Task::Map::Tube>.
 
@@ -204,10 +206,13 @@ L<Map::Tube::Berlin>,
 L<Map::Tube::Bucharest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
+L<Map::Tube::Glasgow>,
 L<Map::Tube::Kazan>,
 L<Map::Tube::Kharkiv>,
 L<Map::Tube::Kiev>,
+L<Map::Tube::KoelnBonn>,
 L<Map::Tube::London>,
+L<Map::Tube::Lyon>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
 L<Map::Tube::Novosibirsk>,
@@ -215,6 +220,7 @@ L<Map::Tube::NYC>,
 L<Map::Tube::Prague>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
+L<Map::Tube::Singapore>,
 L<Map::Tube::Sofia>,
 L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
@@ -239,6 +245,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
